# @hidoo/gulp-task-build-js-browserify

> Task that build javascript by browserify for gulp.

## Installation

```sh
$ npm install --save-dev gulp@next @babel/{core,polyfill,preset-env} @hidoo/gulp-task-build-js-browserify
```

## Usage

```js
import { task } from 'gulp';
import buildJs from '@hidoo/gulp-task-build-js-browserify';

task(
  'js',
  buildJs({
    src: '/path/to/js/main.js',
    dest: '/path/to/dest'
  })
);
```

## API

<!-- Generated by documentation.js. Update this documentation by updating the source code. -->

### buildJs

return javascript build task by browserify

#### Parameters

- `options` **[Object](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Object)** options (optional, default `{}`)

  - `options.name` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** task name (use as displayName) (optional, default `'build:js'`)
  - `options.src` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** source path
  - `options.dest` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** destination path
  - `options.filename` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** destination filename (optional, default `'main.js'`)
  - `options.suffix` **[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)** suffix when compressed (optional, default `'.min'`)
  - `options.targets` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)<[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>?** target browsers.
    see: [default target browsers](http://browserl.ist/?q=%3E+0.5%25+in+JP%2C+ie%3E%3D+10%2C+android+%3E%3D+4.4)
  - `options.browsers` **[Array](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Array)<[String](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/String)>?** alias of options.targets.
  - `options.compress` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** compress file or not (optional, default `false`)
  - `options.verbose` **[Boolean](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Global_Objects/Boolean)** out log or not (optional, default `false`)

#### Examples

```javascript
import { task } from 'gulp';
import buildJs from '@hidoo/gulp-task-build-js-browserify';

task(
  'js',
  buildJs({
    name: 'js:main',
    src: '/path/to/js/main.js',
    dest: '/path/to/dest',
    filename: 'main.js',
    suffix: '.compressed',
    targets: ['> 0.1% in JP'],
    compress: true,
    verbose: true
  })
);
```

Returns **[Function](https://developer.mozilla.org/docs/Web/JavaScript/Reference/Statements/function)<[Stream](https://nodejs.org/api/stream.html)>**&#x20;

## Test

```sh
$ pnpm test
```

## License

MIT
